# pytnix
pytnix, as in **pyt**hon u**NIX**, is an add-on to [The PNU Project](https://github.com/HubTou/PNU), bundling its [UNIX](https://en.wikipedia.org/wiki/Unix) commands rewrites with other [Python](https://www.python.org/) software made by third parties.

## Objectives:
* Having some handy portable Unix tools, for example for Windows (though there are [plenty of other solutions](https://github.com/HubTou/PNU/wiki/Wilderness-Survival-Guide) for that).

## Status:
* You can install what's available from [our package](https://pypi.org/project/pytnix/) with the following console command:
```Shell
pip install pytnix
```

## Commands bundled:
* [The PNU Project](https://github.com/HubTou/PNU)
* [pyfiglet](https://github.com/pwaller/pyfiglet) - a [FIGlet](http://www.figlet.org/) port

